#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_FOUR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_FOUR_HPP_INCLUDED

#include <boost/simd/constant/include/constants/four.hpp>

#endif
